import React, { Component } from 'react';
import { DFPProvider, AdSlot } from 'cnyes-dfp';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import AdProfiles from '../DFPProviderWrapper/AdProfiles';
import styles from './BrandWallSlide.scss';
import Dots from './Dots';

export const BRANDS_WALL_AD_UNIT_SUFFIXES = [['A', 'B', 'C', 'D'], ['E', 'F', 'G', 'H'], ['I', 'J', 'K', 'L']];
const BRAND_WALL_LENGTH = BRANDS_WALL_AD_UNIT_SUFFIXES.length;
const cx = classnames.bind(styles);

class BrandWallSlider extends Component {
  static propTypes = {
    position: PropTypes.oneOf(['Top']),
    delay: PropTypes.number,
    adWidth: PropTypes.number,
  };

  static defaultProps = {
    position: 'Top',
    delay: 2000,
    adWidth: 334,
  };

  state = {
    currentIndex: 0,
  };

  componentDidMount() {
    this.startAutoPlay();
  }

  componentWillUnmount() {
    this.stopAutoPlay();
  }

  onRenderBrandBlock = (block, i) => {
    return (
      <div key={`brand-block-${this.props.position}-${i}`} style={{ width: `${this.props.adWidth}px` }}>
        {block.map(this.onRenderRow)}
      </div>
    );
  };

  onRenderRow = code => {
    const { position } = this.props;

    return (
      <div className={cx('row')} key={`${position}-${code}`}>
        <AdSlot profile={AdProfiles[`brandsWall${position}${code}`]} lazyLoading={false} asyncInit={500} />
      </div>
    );
  };

  stopAutoPlay = () => {
    clearInterval(this.timerId);
  };

  startAutoPlay = () => {
    this.stopAutoPlay();

    this.timerId = setInterval(() => {
      this.handleClickToNext();
    }, this.props.delay);
  };

  handleClickToNext = () => {
    const { currentIndex } = this.state;

    if (currentIndex < BRAND_WALL_LENGTH - 1) {
      this.setState(prev => ({
        currentIndex: prev.currentIndex + 1,
      }));
    } else {
      this.setState({
        currentIndex: 0,
      });
    }
  };

  render() {
    const { adWidth } = this.props;
    const { currentIndex } = this.state;

    return (
      <DFPProvider>
        <div className={cx('container')}>
          <div className={cx('brandWall')}>
            <div style={{ transform: `translateX(-${currentIndex * adWidth}px)` }} className={cx('brandWall__body')}>
              {BRANDS_WALL_AD_UNIT_SUFFIXES.map(this.onRenderBrandBlock)}
            </div>
          </div>
          <div className={cx('dots')}>
            <Dots currentIndex={currentIndex} />
          </div>
        </div>
      </DFPProvider>
    );
  }
}

export default BrandWallSlider;
