import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

import NavItem from './NavItem';
import NavDownloadItem from './NavDownloadItem';
import navConfig from './navConfig';
import styles from './NavBoard.scss';
import getStyleName from '../../../utils/getStyleName';
import { navsMobileType, navDownloadType } from '../../../utils/propTypes';

export default class NavBoard extends PureComponent {
  static propTypes = {
    isCatBoardOpen: PropTypes.bool,
    hideCatBoard: PropTypes.func,
    hideTopBar: PropTypes.bool,
    navs: navsMobileType,
    downloadLinks: navDownloadType,
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
  };

  static defaultProps = {
    isCatBoardOpen: false,
    hideCatBoard: undefined,
    hideTopBar: false,
    navs: navConfig,
    downloadLinks: [],
    dataPrefix: ['data-proj-ga'],
  };

  render() {
    const { hideTopBar, isCatBoardOpen, hideCatBoard, navs, downloadLinks, dataPrefix } = this.props;
    const catBoardClassName = isCatBoardOpen ? styles['nav-board-show'] : styles['nav-board'];

    return (
      <aside
        className={cx(catBoardClassName, 'theme-gradient', {
          [getStyleName(styles, 'nav-board-top-bar')]: !hideTopBar,
        })}
      >
        <header>
          <span className={styles['nav-board-logo']}>鉅亨</span>
          <button className={styles['nav-board-btn-close']} onClick={hideCatBoard} />
        </header>
        <main>
          {downloadLinks.map(link => [
            <h4 key={`link-${link.title}`} className={styles['cat-board-nav-link']}>
              <NavDownloadItem title={link.title} url={link.url} />
            </h4>,
          ])}
          {navs.map(nav => [
            nav.url ? (
              <a href={nav.url} key={`${nav.name}-h4`}>
                <h4 className="nav-board-subtitle theme-nav-board-subtitle">{nav.title}</h4>
              </a>
            ) : (
              <h4 key={`${nav.name}-h4`} className="nav-board-subtitle theme-nav-board-subtitle">
                {nav.title}
              </h4>
            ),
            <nav key={`${nav.name}-nav`} className={styles['cat-board-nav']}>
              {nav.items &&
                nav.items.map(item => (
                  <NavItem
                    key={item.name}
                    navTitle={nav.title}
                    item={item}
                    onClick={hideCatBoard}
                    dataPrefix={dataPrefix}
                  />
                ))}
            </nav>,
          ])}
        </main>
      </aside>
    );
  }
}
