/**
 * Get the corresponding url.
 * @param {*} env prod | stage | beta | int
 */
export default function AnueLink(env) {
  const isProd = env === 'prod';
  const isApiProd = env !== 'int' && env !== 'beta';
  const cnyesBaseUrl = isProd ? 'cnyes.com' : `${env}.cnyes.cool`;
  const cookieDomain = isProd ? '.cnyes.com' : '.cnyes.cool';
  const apiBaseUrl = isApiProd ? 'cnyes.com' : `${env}.cnyes.cool`;

  const wwwChannelLink = `https://www.${cnyesBaseUrl}`;
  const newsChannelLink = `https://news.${cnyesBaseUrl}`;
  const cryptoChannelLink = `https://crypto.${cnyesBaseUrl}`;
  const fundChannelLink = `https://fund.${cnyesBaseUrl}`;
  const stockTalk = `https://stock.${cnyesBaseUrl}`;
  const globalStockTalk = `https://global-stock.${cnyesBaseUrl}`;
  const invest = `https://invest.${cnyesBaseUrl}`;
  const desktopFundsSearch = `${fundChannelLink}/search`;
  const mobileFundsSearch = `${invest}/funds/search`;

  const forexChannelLink = `${wwwChannelLink}/forex/reuters`;
  const forexCrossListLink = `${wwwChannelLink}/forex/crosslist`;
  const cryptoChannelBTCLink = `${cryptoChannelLink}/BTC/24h`;
  const wdStockNewsLink = `${newsChannelLink}/news/cat/wd_stock`;
  const forexNewsLink = `${newsChannelLink}/news/cat/forex`;
  const cryptoNewsLink = `${newsChannelLink}/news/cat/bc_virtual`;
  const bcNewsLink = `${newsChannelLink}/news/cat/bc`;
  const fundNewsLink = `${newsChannelLink}/news/cat/fund`;
  const twStockNewsLink = `${newsChannelLink}/news/cat/tw_stock`;
  const usStockNewsLink = `${newsChannelLink}/news/cat/us_stock`;
  const cnStockNewsLink = `${newsChannelLink}/news/cat/cn_stock`;
  const topTopicsNewsLink = `${newsChannelLink}/news/cat/topTopics`;
  const magNewsLink = `${newsChannelLink}/news/cat/mag`;
  const projectNewsLink = `${newsChannelLink}/projects/cat/all`;

  const driverFundDetailLink = `${invest}/funds/detail`;
  const driverPageLink = `${invest}/drivers`;
  const driverSearchLink = `${invest}/drivers/search`;
  const forexDetailPageLink = `${invest}/forex/detail`;
  const newsTagLink = `${newsChannelLink}/tag`;
  const newsDetailLink = `${newsChannelLink}/news/id`;
  const hotTagsApiUrl = `https://api.${apiBaseUrl}/api/v1/news/recommend/tags`;
  const hotDriversApiUrl = `https://driver.api.${apiBaseUrl}/driver/api/v1/drivers?order=1y&sort=desc&page=1&size=3`;
  const hotTradesApiUrl = `https://ws.api.${apiBaseUrl}/ws/api/v1/ga/pageViewHot`;
  // limit the categories for first version
  const anueSearchAllCategory = 'TW,FUND,US,CC,INDEX,FUTURE,ETF,FX,EOD';
  const anueSearchAllApiUrl = `https://ess.api.${apiBaseUrl}/ess/api/v1/siteSearch/main?category=${anueSearchAllCategory}&q=`;

  // .net link only have prod env
  const archiveStockQLink = 'https://money.cnyes.com/archive/StockQ.aspx';
  const wdStockChannelLink = 'https://www.cnyes.com/global/IndexImmediateQuotedPrice/';
  const archiveUSStock = 'https://www.cnyes.com/archive/usastock/';
  const archiveTWStock = 'https://www.cnyes.com/archive/twstock';
  const archiveTWGStock = 'https://www.cnyes.com/archive/presh';
  const newsAppDownloadLink = 'https://www.cnyes.com/mobile/index_app.htm';
  const feedbackLink = 'https://docs.google.com/forms/d/1QvhPSjjG-vrxPUvpzGd2uYmFiIs1cMu1luFAwSonm6U/viewform';
  const feedbackEntryUrlId = '1831304503';

  const toUrlParams = params => {
    return Object.keys(params)
      .filter(key => !!params[key])
      .map(key => `${encodeURIComponent(key)}=${encodeURIComponent(params[key])}`)
      .join('&');
  };

  /**
   * https://cnyesrd.atlassian.net/wiki/spaces/PS/pages/637993057
   * symbol = [market]:[xxx]:[mType]
   * objectType: 主要用來區分是否為基金商品 *exception: /ga/pageViewHot 回覆在 market 欄位而非 objectType
   * type: 無法從 symbol 區分出來的細分類, 如 ETF
   */

  return {
    generateStockLinkBySymbol: (symbol, type) => {
      const symbolSplit = String(symbol).split(':');

      if (!symbolSplit || symbolSplit.length < 2) {
        return '';
      }

      // GF：symbol：FUTURES, TWF：symbol：FUTURES
      if ((symbolSplit[0] === 'TWF' || symbolSplit[0] === 'GF') && symbolSplit[2] === 'FUTURES') {
        return `${invest}/futures/${symbolSplit[0]}/${symbolSplit[1]}`;
      }

      // GI：symbol：INDEX, TWS：symbol：INDEX
      if ((symbolSplit[0] === 'TWS' || symbolSplit[0] === 'GI') && symbolSplit[2] === 'INDEX') {
        return `${invest}/index/${symbolSplit[0]}/${symbolSplit[1]}`;
      }

      if ((symbolSplit[0] === 'TWS' || symbolSplit[0] === 'TWG') && symbolSplit[2] === 'STOCK') {
        return `${invest}/twstock/${symbolSplit[0]}/${symbolSplit[1]}`;
      }

      if ((symbolSplit[0] === 'CNS' || symbolSplit[0] === 'HKS') && symbolSplit[2] === 'STOCK') {
        return `${globalStockTalk}/market/${symbol}`;
      }

      // USS：symbol：STOCK，type：ETF
      if (symbolSplit[0] === 'USS' && symbolSplit[2] === 'STOCK') {
        if (type && type === 'ETF') {
          return `${invest}/ETF/US/detail/${symbolSplit[1]}`;
        }

        return `${invest}/usstock/detail/${symbolSplit[1]}`;
      }

      if (symbolSplit[0] === 'FX') {
        return `${forexDetailPageLink}/${symbolSplit[1]}/overview`;
      }

      if (symbolSplit[0] === 'EOD') {
        return `${invest}/eod/detail/${symbolSplit[1]}`;
      }

      if (symbolSplit[0] === 'CC' && symbolSplit[1]) {
        const crypto = symbolSplit[1];

        return `${cryptoChannelLink}/${crypto}`;
      }

      return '';
    },
    generateFundLink: (displayName, cnyesId) => {
      const fundName = `${displayName}`.replace(/<(?:.|\n)*?>/gm, '');

      return `${driverFundDetailLink}/${fundName}/${cnyesId}`;
    },
    generateFundSaleLink: ({ forSale, displayNameLocal, cnyesId, source, medium, campaign }) => {
      const paramList = [];
      const params = {
        utm_source: source,
        utm_medium: medium,
        utm_campaign: campaign,
      };

      Object.keys(params).forEach(p => {
        if (params[p]) {
          paramList.push(`${p}=${params[p]}`);
        }
      });

      if (forSale === 1) {
        let url = `${invest}/funds/order/${displayNameLocal}/${cnyesId}`;

        if (paramList.length > 0) {
          url += `?${paramList.join('&')}`;
        }

        return url;
      }

      return '';
    },
    generateETFLink: symbol => {
      const symbolSplit = String(symbol).split(':');

      if (!symbolSplit || symbolSplit.length < 2) {
        return '';
      }

      if (symbolSplit[0] === 'TWS' && symbolSplit[2] === 'STOCK') {
        return `${stockTalk}/market/TWS:${symbolSplit[1]}:${symbolSplit[2]}`;
      }

      if (symbolSplit[0] === 'USS' && symbolSplit[2] === 'STOCK') {
        return `${invest}/etf/us/detail/${symbolSplit[1]}`;
      }

      return '';
    },
    generateSearchResultLink: ({ keyword, backLink }) => {
      const params = {
        keyword,
        aink: backLink,
      };

      return `${wwwChannelLink}/search/all?${toUrlParams(params)}`;
    },
    generateForexLink: symbol => {
      const symbolSplit = String(symbol).split(':');

      if (!symbolSplit || symbolSplit.length < 2) {
        return '';
      }

      if (symbolSplit[0] === 'FX') {
        return `${forexDetailPageLink}/${symbolSplit[1]}/overview`;
      }

      return '';
    },
    generateFeedbackLink: (url = '') => {
      let entryUrl = url;

      if (!url && typeof window !== 'undefined') {
        entryUrl = window.location.href;
      }

      return `${feedbackLink}?usp=pp_url&entry.${feedbackEntryUrlId}=${encodeURIComponent(entryUrl)}`;
    },
    cnyesBaseUrl,
    cookieDomain,
    wwwChannelLink,
    newsChannelLink,
    cryptoChannelLink,
    fundChannelLink,
    stockTalk,
    globalStockTalk,
    invest,
    forexChannelLink,
    forexCrossListLink,
    cryptoChannelBTCLink,
    wdStockNewsLink,
    forexNewsLink,
    cryptoNewsLink,
    bcNewsLink,
    fundNewsLink,
    twStockNewsLink,
    usStockNewsLink,
    cnStockNewsLink,
    wdStockChannelLink,
    topTopicsNewsLink,
    magNewsLink,
    projectNewsLink,
    archiveStockQLink,
    archiveUSStock,
    archiveTWStock,
    archiveTWGStock,
    driverFundDetailLink,
    driverPageLink,
    driverSearchLink,
    newsTagLink,
    newsDetailLink,
    hotTagsApiUrl,
    hotDriversApiUrl,
    anueSearchAllApiUrl,
    hotTradesApiUrl,
    toUrlParams,
    desktopFundsSearch,
    mobileFundsSearch,
    anueSearchAllCategory,
    newsAppDownloadLink,
    feedbackLink,
  };
}
